==> smartgwt-4.1p.zip: com/smartgwt/logicalstructure/widgets/BatchUploaderLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class BatchUploaderLogicalStructure extends CanvasLogicalStructure {
    public String cancelConfirmMessage;
    public String commitConfirmationMessage;
    public String dataURL;
    public String defaultDelimiter;
    public String defaultQuoteString;
    public String partialCommit;
    public String partialCommitError;
    public String partialCommitPrompt;
    public String requestProperties;
    public String showCommitConfirmation;
    public String uploadButtonTitle;
    public DataSource uploadDataSource;
    public String uploadFieldPrefix;
    public String uploadFileLabel;
    public String[] uploadFormFields;
    public String uploadOperation;
    public String warnOnCancel;
}

==> smartgwt-12.0p.zip: com/smartgwt/logicalstructure/widgets/BatchUploaderLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class BatchUploaderLogicalStructure extends VStackLogicalStructure {
    public String allRecordsInErrorMessage;
    public String autoInterpretBooleans;
    public String cancelButtonTitle;
    public String cancelConfirmMessage;
    public String commitButtonTitle;
    public String commitConfirmationMessage;
    public String dataFormat;
    public String dataURL;
    public String defaultDelimiter;
    public String defaultQuoteString;
    public String discardedColumnsMessage;
    public String displayDiscardedColumns;
    public String errorMessageDelimiterOrEndOfLine;
    public String errorMessageExcelFileDetected;
    public String errorMessageFileIsBlank;
    public String errorMessageInputType;
    public String errorMessageRowsNotParsed;
    public String errorMessageUndeterminedDelimiter;
    public String errorMessageUnterminatedQuote;
    public String nextButtonTitle;
    public String partialCommit;
    public String partialCommitConfirmationMessage;
    public String partialCommitError;
    public String partialCommitPrompt;
    public String previousButtonTitle;
    public DSRequest requestProperties;
    public String showCommitConfirmation;
    public String updatesRolledBackMessage;
    public String uploadButtonTitle;
    public DataSource uploadDataSource;
    public String uploadDelimiter;
    public String uploadEncoding;
    public String uploadFieldPrefix;
    public String uploadFileLabel;
    public String uploadOperation;
    public String uploadQuoteString;
    public String warnOnCancel;
}
